@@ -76,6 +76,8 @@ def projview(
     format="%g",
     cbar=True,
     cmap="viridis",
+    badcolor="grey",
+    bgcolor="white",
     norm=None,
     norm_dict=None,
     graticule=False,
@@ -140,9 +142,10 @@ def projview(
       center. An additional rotation of angle *psi* around this direction is
       applied.
     coord : sequence of character, optional
-      Either one of 'G', 'E' or 'C' to describe the coordinate system of the
-      map, or a sequence of 2 of these to rotate the map from the first to the
-      second coordinate system. default: 'G'
+      Either one of 'G', 'E' or 'C' (where 'E' stands for the Ecliptic, 'G' for 
+      the Galactic, and 'C' for the Celestial or equatorial) to describe the coordinate
+      system of the map, or a sequence of 2 of these to rotate the map from the first 
+      to the second coordinate system. default: 'G'
     unit : str, optional
       A text describing the unit of the data. Default: ''
     xsize : int, optional
@@ -167,6 +170,10 @@ def projview(
       Display the colorbar. Default: True
     cmap : str, optional
         Specify the colormap. default: Viridis
+    badcolor: str, optional
+        Specify the color of bad pixels. default: Grey
+    bgcolor: str, optional
+        Specify the color of the background. default: White
     norm : {'hist', 'log', 'symlog', 'symlog2', None}
       Color normalization:
       hist = histogram equalized color mapping.
@@ -187,8 +194,9 @@ def projview(
     rot_graticule : bool
       rotate also the graticule when rotating the map
     graticule_coord : str
-      Either one of 'G', 'E' or 'C' to describe the coordinate system of the
-      graticule
+      Either one of 'G', 'E' or 'C' (where 'E' stands for the Ecliptic, 'G' for
+      the Galactic system, and 'C' for the Celestial or equatorial system) to
+      describe the coordinate system of the graticule
     override_rot_graticule_properties : dict
       Override the following rotated graticule properties: "g_linestyle",
       "g_linewidth", "g_color", "g_alpha", "t_step", "p_step".
@@ -548,7 +556,7 @@ def projview(
                 max = m[w].max()
 
         cm, nn = get_color_table(
-            min, max, m[w], cmap=cmap, norm=norm, **norm_dict_defaults
+            min, max, m[w], cmap=cmap, norm=norm, badcolor=badcolor, bgcolor=bgcolor, **norm_dict_defaults
         )
         grid_pix = ang2pix(nside, THETA, PHI, nest=nest)
         grid_map = m[grid_pix]
