@@ -352,7 +352,7 @@ def map2alm_lsq(maps, lmax, mmax, pol=True, tol=1e-10, maxiter=20):
         the number of iterations required
     """
     from scipy.sparse.linalg import LinearOperator, lsqr, lsmr
-    from scipy.linalg import norm
+    from numpy.linalg import norm
 
     maps = ma_to_array(maps)
     info = maptype(maps)
@@ -396,8 +396,13 @@ def map2alm_lsq(maps, lmax, mmax, pol=True, tol=1e-10, maxiter=20):
 
     # initial guess
     alm0 = m2a2(maps) / npix * (4 * np.pi)
+
+    # We are explicitly setting "dtype" for the LinearOperator here because
+    # some (inadvertent?) changes in scipy 1.15 made this necessary
+    # (see, e.g., https://github.com/scipy/scipy/issues/22310).
     op = LinearOperator(
-        matvec=a2m2, rmatvec=m2a2, shape=(len(maps) * maps[0].size, alm0.size)
+        matvec=a2m2, rmatvec=m2a2, shape=(len(maps) * maps[0].size, alm0.size),
+        dtype=alm0.real.dtype
     )
     res = lsqr(
         A=op,
